@@ -1,14 +1,33 @@
 import unittest
+import logging
 from translit_me.transliterator import transliterate as tr
 from translit_me.lang_tables import *
+import sys
+# sys.stdout.reconfigure(encoding='utf-8')
+
 
 
 class TestTransliterate(unittest.TestCase):
     def test_hebrew_arabic(self):
+        # This is effective if the output is piped or redirected.
+        logging.basicConfig(level=logging.DEBUG, encoding='utf-8')
+
         names = ['נועַם', "מאנץ'", "בישינה", "דימונה"]
         expected = ['نوعَم', 'مانض', 'بيشينة', 'بيسينة', 'ديمونة', 'ضيمونة']
         res = tr(names, HE_AR)
-        print(res)
+        logging._defaultFormatter = logging.Formatter(u"%(message)s")
+        logging.info(res)
+        self.assertListEqual(res, expected)
+
+    def test_arabic_hebrew(self):
+        logging.basicConfig(level=logging.DEBUG, encoding='utf-8')
+
+        names = ['نوعَم', 'مانض', 'بيشينة', 'بيسينة', 'ديمونة', 'الجزائر']
+        expected = ['נועַם', "מאנץ'", "בישינה", "דימונה"]
+
+        res = tr(names, AR_HE)
+        logging._defaultFormatter = logging.Formatter(u"%(message)s")
+        logging.info(res)
         self.assertListEqual(res, expected)
 
     def test_hebrew_english(self):
